@@ -187,7 +187,7 @@ void MicrophoneIndicator::setMuted(bool muted)
     }
 
     // Otherwise unmute the devices we muted
-    for (auto &idx : qAsConst(m_mutedIndices)) {
+    for (auto &idx : std::as_const(m_mutedIndices)) {
         if (!idx.isValid()) {
             continue;
         }
@@ -241,9 +241,9 @@ void MicrophoneIndicator::showOsd()
     m_osd->showMicrophone(volumePercent(preferredSource));
 }
 
-QVector<QModelIndex> MicrophoneIndicator::recordingApplications() const
+QList<QModelIndex> MicrophoneIndicator::recordingApplications() const
 {
-    QVector<QModelIndex> indices;
+    QList<QModelIndex> indices;
 
     // If there are no microphones present, there's nothing to record
     if (m_sourceModel->rowCount() == 0) {
@@ -268,7 +268,7 @@ QVector<QModelIndex> MicrophoneIndicator::recordingApplications() const
     return indices;
 }
 
-QString MicrophoneIndicator::toolTipForApps(const QVector<QModelIndex> &apps) const
+QString MicrophoneIndicator::toolTipForApps(const QList<QModelIndex> &apps) const
 {
     Q_ASSERT(!apps.isEmpty());
 
